@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2000-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 2000-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you did
  * did not receive this file, see http://www.horde.org/licenses/apache.
  *
  * @category  Horde
- * @copyright 2000-2015 Horde LLC
+ * @copyright 2000-2016 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Turba
  */
@@ -17,7 +17,7 @@
  * @author    Chuck Hagenbuch <chuck@horde.org>
  * @author    Jon Parise <jon@horde.org>
  * @category  Horde
- * @copyright 2000-2015 Horde LLC
+ * @copyright 2000-2016 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Turba
  */
@@ -708,4 +708,25 @@ class Turba
             'TurbaBrowse.submit' => _("Are you sure that you want to delete the selected contacts?")
         ));
     }
+
+    /**
+     * Return an array of all available attributes of type 'email'.
+     *
+     * @return array  An array of email fields.
+     * @since  4.2.9
+     */
+    public static function getAvailableEmailFields()
+    {
+        global $attributes;
+
+        $emailFields = array();
+        foreach ($attributes as $field => $data) {
+            if ($data['type'] == 'email') {
+                $emailFields[] = $field;
+            }
+        }
+
+        return $emailFields;
+    }
+
 }
